@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-29 11:00:52
-:LastEditTime: 2021-01-06 15:36:02
+:LastEditTime: 2021-06-25 11:43:58
 :LastEditors: ChenXiaolei
 :Description: 文件上传信息
 """
@@ -11,6 +11,7 @@ from io import BytesIO
 from seven_studio.libs.file.ks3 import *
 from seven_studio.libs.file.oss2 import *
 from seven_studio.libs.file.cos import *
+from seven_studio.libs.file.bos import *
 from seven_studio.utils.random import *
 from seven_framework.time import *
 from seven_framework.uuid import *
@@ -207,45 +208,22 @@ class FileUpload():
         elif file_storage_path.StorageTypeID == 3:
             # FastDFS文件服务器
             pass
-        elif file_storage_path.StorageTypeID == 4:
-            # 金山云
-            invoke_result = KS3.upload(file_storage_path.StorageConfig,
+        elif file_storage_path.StorageTypeID in (4, 5, 6, 7):
+            if file_storage_path.StorageTypeID == 4:
+                # 金山云
+                invoke_result = KS3.upload(file_storage_path.StorageConfig,
                                            file_name, stream)
-
-            if invoke_result.ResultCode != "0":
-                return invoke_result
-
-            if invoke_result.Data:
-                file_upload_info.Md5Value = invoke_result.Data["Md5Value"]
-                file_upload_info.ResourcePath = invoke_result.Data[
-                    "ResourcePath"]
-                file_upload_info.OriginalName = invoke_result.Data[
-                    "OriginalName"]
-                file_upload_info.FilePath = invoke_result.Data["FilePath"]
-                file_upload_info.ImageWidth = invoke_result.Data["ImageWidth"]
-                file_upload_info.ImageHeight = invoke_result.Data[
-                    "ImageHeight"]
-        elif file_storage_path.StorageTypeID == 5:
-            # 阿里云
-            invoke_result = OSS2.upload(file_storage_path.StorageConfig,
+            elif file_storage_path.StorageTypeID == 5:
+                # 金山云
+                invoke_result = KS3.upload(file_storage_path.StorageConfig,
                                            file_name, stream)
-
-            if invoke_result.ResultCode != "0":
-                return invoke_result
-
-            if invoke_result.Data:
-                file_upload_info.Md5Value = invoke_result.Data["Md5Value"]
-                file_upload_info.ResourcePath = invoke_result.Data[
-                    "ResourcePath"]
-                file_upload_info.OriginalName = invoke_result.Data[
-                    "OriginalName"]
-                file_upload_info.FilePath = invoke_result.Data["FilePath"]
-                file_upload_info.ImageWidth = invoke_result.Data["ImageWidth"]
-                file_upload_info.ImageHeight = invoke_result.Data[
-                    "ImageHeight"]
-        elif file_storage_path.StorageTypeID == 6:
-            # 腾讯云
-            invoke_result = COS.upload(file_storage_path.StorageConfig,
+            elif file_storage_path.StorageTypeID == 6:
+                # 腾讯云
+                invoke_result = COS.upload(file_storage_path.StorageConfig,
+                                           file_name, stream)
+            elif file_storage_path.StorageTypeID == 7:
+                # 百度云
+                invoke_result = BOS.upload(file_storage_path.StorageConfig,
                                            file_name, stream)
 
             if invoke_result.ResultCode != "0":
@@ -378,4 +356,4 @@ class FileUpload():
                 resource_directory,
                 os.path.splitext(resource_uuid_file_name)[0])
 
-        return resource_directory
\ No newline at end of file
+        return resource_directory
