@@ -1,11 +1,11 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-15 09:56:24
-:LastEditTime: 2021-02-03 16:38:43
+:LastEditTime: 2021-06-30 19:19:11
 :LastEditors: HuangJingCan
 :Description: 权限角色栏目相关
 """
-
+from asq.initiators import query
 from seven_studio.utils.dict import *
 from seven_framework.time import *
 
@@ -48,7 +48,9 @@ class PowerModel():
             role_user_list = RoleUserModel(manage_context_key).get_list("UserID=%s", params=self.user_id)
             if len(role_user_list) == 0:
                 return menu_info_list
-            self.ROLE_POWERS = RolePowerModelEx(manage_context_key).get_role_power_list([i.RoleID for i in role_user_list])
+            # self.ROLE_POWERS = RolePowerModelEx(manage_context_key).get_role_power_list([i.RoleID for i in role_user_list])
+            role_power_list = RolePowerModelEx(manage_context_key).get_role_power_list([i.RoleID for i in role_user_list])
+            self.ROLE_POWERS = RolePowerEx().get_list_by_role_power_list(role_power_list)
             condition = "IsPower=0"
             if len(self.ROLE_POWERS) > 0:
                 condition += " OR "
@@ -81,7 +83,8 @@ class PowerModel():
             self.__get_menu_item_dto_list(curr_menu_item_dto, menu_info_list, hidden_power_menu_list)
             if menu_info.MenuCoteID > 0:
                 menu_list = self.__get_power_cote_menu_item(menu_info.MenuCoteID, curr_menu_item_dto, (self.is_super or menu_info.IsPower == 0))
-                if len(menu_list) > 0:
+                # if len(menu_list) > 0:
+                if menu_list:
                     curr_menu_item_dto.MenuItemDtoList = menu_list
             menu_item_list.append(curr_menu_item_dto.__dict__)
         return menu_item_list
@@ -206,7 +209,8 @@ class PowerModel():
             condition = f"{menu_cote.Condtion} ORDER BY {menu_cote.SortExpression}"
 
         sql = f"SELECT {field_parms} FROM {menu_cote.CoteTableName}{condition}"
-        list_row = MySQLHelper(config.get_value(self.db_connect_key)).fetch_all_rows(sql)
+        # list_row = MySQLHelper(config.get_value(self.db_connect_key)).fetch_all_rows(sql)
+        list_row = MySQLHelper(config.get_value(menu_cote.ConnectionStringName)).fetch_all_rows(sql)
         return list_row
 
     def __check_menu_power(self, is_power, menu_id, cote_id):
@@ -227,7 +231,7 @@ class PowerModel():
                 self.__get_child_cote_menu_list(root_power_menu_list, button_menu_dto_list, curr_menu_item_dto, menu_info_list, is_super)
             else:
                 for curr_power_button_dto in button_menu_dto_list:
-                    if is_super or [i for i in self.ROLE_POWERS if i.MenuCoteID in (curr_power_button_dto.ID + "$" + curr_menu_info["TargetUrl"])]:
+                    if is_super or [i for i in self.ROLE_POWERS if i.MenuCoteID in (curr_power_button_dto['ID'] + "$" + curr_menu_info["TargetUrl"])]:
                         curr_menu_item_dto.MenuButtonDtoList.append(curr_power_button_dto)
                 curr_menu_item_dto.MenuItemDtoList.extend(self.__to_cote_menu_list(root_power_menu_list, curr_menu_info["TargetUrl"], is_super))
                 menu_item.MenuItemDtoList.extend(self.__to_cote_menu_list(root_power_menu_list, curr_menu_info["TargetUrl"], is_super, True))
@@ -243,28 +247,24 @@ class PowerModel():
                 curr_menu_item_dto.MenuItemDtoList.append(childInfo.__dict__)
 
     def __to_cote_menu_list(self, menu_info_list, menu_cote_key, is_super, is_hidden=False):
-        menu_item_list = []
-        role_powers = [i for i in self.ROLE_POWERS if i.MenuCoteID in (i.MenuID + "$" + menu_cote_key)]
-        if is_super or role_powers:
-            menu_item_list = role_powers
+        menu_item_list = menu_info_list if is_super else query(menu_info_list).where(lambda x: query(self.ROLE_POWERS).select(lambda y: y["MenuCoteID"]).contains(str(x["MenuID"]) + "$" + menu_cote_key)).to_list()
         for curr_power_menu_info_dto in menu_item_list:
-            curr_power_menu_info_dto.MenuID = curr_power_menu_info_dto.MenuID + "$" + menu_cote_key
-            curr_power_menu_info_dto.Path = "/" + curr_power_menu_info_dto.MenuID + curr_power_menu_info_dto.ViewPath
+            curr_power_menu_info_dto['MenuID'] = curr_power_menu_info_dto['MenuID'] + "$" + menu_cote_key
+            curr_power_menu_info_dto['Path'] = "/" + curr_power_menu_info_dto['MenuID'] + curr_power_menu_info_dto['ViewPath']
 
             if is_hidden:
-                curr_power_menu_info_dto.MenuID = curr_power_menu_info_dto.MenuID + "hidden"
+                curr_power_menu_info_dto['MenuID'] = curr_power_menu_info_dto['ViewPath'] + "hidden"
 
-            role_powers_curr = [i for i in self.ROLE_POWERS if i.MenuCoteID in (i.ID + "$" + menu_cote_key)]
-            if is_super or role_powers_curr:
-                curr_power_menu_info_dto.MenuButtonDtoList = role_powers_curr
+            c_menu_list = curr_power_menu_info_dto['MenuButtonDtoList']
+            curr_power_menu_info_dto['MenuButtonDtoList'] = c_menu_list if is_super else query(c_menu_list).where(lambda x: query(self.ROLE_POWERS).select(lambda y: y["MenuCoteID"]).contains(str(x["ID"]) + "$" + menu_cote_key)).to_list()
 
-            curr_power_menu_info_dto.IsHidden = True if curr_power_menu_info_dto.IsHidden else is_hidden
+            curr_power_menu_info_dto['IsHidden'] = True if curr_power_menu_info_dto['IsHidden'] else is_hidden
 
-            if len(curr_power_menu_info_dto.MenuItemDtoList) == 1:
-                curr_power_menu_info_dto.MenuItemDtoList[0].MenuID = curr_power_menu_info_dto.MenuID + ":Child"
-                curr_power_menu_info_dto.MenuItemDtoList[0].Path = curr_power_menu_info_dto.Path
-            elif len(curr_power_menu_info_dto.MenuItemDtoList) > 1:
-                curr_power_menu_info_dto.MenuItemDtoList = self.__to_cote_menu_list(curr_power_menu_info_dto.MenuItemDtoList, menu_cote_key, is_super, is_hidden)
+            if len(curr_power_menu_info_dto['MenuItemDtoList']) == 1:
+                curr_power_menu_info_dto['MenuItemDtoList'][0]['MenuID'] = curr_power_menu_info_dto['MenuID'] + ":Child"
+                curr_power_menu_info_dto['MenuItemDtoList'][0]['Path'] = curr_power_menu_info_dto['Path']
+            elif len(curr_power_menu_info_dto['MenuItemDtoList']) > 1:
+                curr_power_menu_info_dto['MenuItemDtoList'] = self.__to_cote_menu_list(curr_power_menu_info_dto['MenuItemDtoList'], menu_cote_key, is_super, is_hidden)
 
         return menu_item_list
 
@@ -318,9 +318,9 @@ class PowerModel():
                 if self.__check_menu_power(self.is_super, curr_menu_info.MenuID, dr[menu_cote.IDName]):
                     continue
                 cote_menu_info = MenuInfo()
-                cote_menu_info.MenuID = cote_id + dr[menu_cote.IDName]
+                cote_menu_info.MenuID = cote_id + str(dr[menu_cote.IDName])
                 cote_menu_info.MenuName = dr[menu_cote.Name]
-                cote_menu_info.ParentID = cote_id + dr[menu_cote.ParentIDName] if menu_cote.ParentIDName != "" else cote_id + menu_cote.RootIDValue
+                cote_menu_info.ParentID = cote_id + str(dr[menu_cote.ParentIDName]) if menu_cote.ParentIDName != "" else cote_id + menu_cote.RootIDValue
                 cote_menu_info.IDPath = dr[menu_cote.IDPathName] if menu_cote.IDPathName != "" else ""
                 cote_menu_info.TargetUrl = dr[menu_cote.IDName]
                 cote_menu_info_list.append(cote_menu_info.__dict__)
@@ -333,16 +333,16 @@ class PowerModel():
                     curr_child_menu_info = []
                     for c_menu_info_dto in child_menu_info_list:
                         new_c_menu_info_dto = MenuInfoDto()
-                        new_c_menu_info_dto.MenuID = c_menu_info_dto.MenuID + "$" + menu_info.TargetUrl
-                        new_c_menu_info_dto.MenuName = c_menu_info_dto.MenuName
-                        new_c_menu_info_dto.MenuIcon = c_menu_info_dto.MenuIcon
-                        new_c_menu_info_dto.ParentID = c_menu_info_dto.MenuID
-                        new_c_menu_info_dto.IDPath = c_menu_info_dto.IDPath
-                        new_c_menu_info_dto.ChildList = c_menu_info_dto.ChildList
+                        new_c_menu_info_dto.MenuID = c_menu_info_dto['MenuID'] + "$" + str(menu_info['TargetUrl'])
+                        new_c_menu_info_dto.MenuName = c_menu_info_dto['MenuName']
+                        new_c_menu_info_dto.MenuIcon = c_menu_info_dto['MenuIcon']
+                        new_c_menu_info_dto.ParentID = c_menu_info_dto['MenuID']
+                        new_c_menu_info_dto.IDPath = c_menu_info_dto['IDPath']
+                        new_c_menu_info_dto.ChildList = c_menu_info_dto['ChildList']
                         for info in new_c_menu_info_dto.ChildList:
-                            info.MenuID = info.MenuID + "$" + curr_menu_info.TargetUrl
-                            info.ParentID = info.ParentID + "$" + menu_info.TargetUrl
-                            self.__revise_child_cote_menu_list(info, menu_info.TargetUrl)
+                            info['MenuID'] = info['MenuID'] + "$" + curr_menu_info.TargetUrl
+                            info['ParentID'] = str(info['ParentID']) + "$" + str(menu_info['TargetUrl'])
+                            self.__revise_child_cote_menu_list(info, menu_info['TargetUrl'])
 
                         curr_child_menu_info.append(new_c_menu_info_dto.__dict__)
 
@@ -353,38 +353,38 @@ class PowerModel():
         return menu_item_list
 
     def __revise_child_cote_menu_list(self, menu_info_dto, cote_key):
-        if menu_info_dto.ChildList:
-            for info in menu_info_dto.ChildList:
-                info.MenuID = info.MenuID + "$" + cote_key
-                info.ParentID = info.ParentID + "$" + cote_key
+        if menu_info_dto['ChildList']:
+            for info in menu_info_dto['ChildList']:
+                info['MenuID'] = str(info['MenuID']) + "$" + str(cote_key)
+                info['ParentID'] = str(info['ParentID']) + "$" + str(cote_key)
                 self.__revise_child_cote_menu_list(info, cote_key)
 
     def __get_child_cote_menu_item_list(self, menu_item, menu_infos, child_menu_info_list):
         menu_item_list = []
-        for curr_menu_info in [i for i in menu_infos if i.ParentID == menu_item.MenuID]:
-            curr_menu_dto = DictUtil.auto_mapper(MenuInfoDto(), curr_menu_info.__dict__)
-            child_menu_list = [i for i in menu_infos if i.ParentID == curr_menu_info.MenuID]
-            if child_menu_list:
-                curr_child_menu_info = []
+        for curr_menu_info in [i for i in menu_infos if i['ParentID'] == menu_item.MenuID]:
+            curr_child_menu_info = []
+            curr_menu_dto = DictUtil.auto_mapper(MenuInfoDto(), curr_menu_info)
+            child_menu_list = [i for i in menu_infos if i['ParentID'] == curr_menu_info['MenuID']]
+            if not child_menu_list:
                 for c_menu_info_dto in child_menu_info_list:
                     new_c_menu_info_dto = MenuInfoDto()
-                    new_c_menu_info_dto.MenuID = c_menu_info_dto.MenuID + "$" + curr_menu_info.TargetUrl
-                    new_c_menu_info_dto.MenuIcon = c_menu_info_dto.MenuIcon
-                    new_c_menu_info_dto.MenuName = c_menu_info_dto.MenuName
-                    new_c_menu_info_dto.ParentID = curr_menu_info.MenuID + "$" + curr_menu_info.TargetUrl
-                    new_c_menu_info_dto.IDPath = c_menu_info_dto.IDPath
-                    new_c_menu_info_dto.ChildList = c_menu_info_dto.ChildList
-                    for info in c_menu_info_dto.ChildList:
-                        info.MenuID = info.MenuID + "$" + curr_menu_info.TargetUrl
+                    new_c_menu_info_dto.MenuID = str(c_menu_info_dto['MenuID']) + "$" + str(curr_menu_info['TargetUrl'])
+                    new_c_menu_info_dto.MenuIcon = c_menu_info_dto['MenuIcon']
+                    new_c_menu_info_dto.MenuName = c_menu_info_dto['MenuName']
+                    new_c_menu_info_dto.ParentID = str(curr_menu_info['MenuID']) + "$" + str(curr_menu_info['TargetUrl'])
+                    new_c_menu_info_dto.IDPath = c_menu_info_dto['IDPath']
+                    new_c_menu_info_dto.ChildList = c_menu_info_dto['ChildList']
+                    for info in c_menu_info_dto['ChildList']:
+                        info['MenuID'] = str(info['MenuID']) + "$" + str(curr_menu_info['TargetUrl'])
 
                     curr_child_menu_info.append(new_c_menu_info_dto.__dict__)
 
-                curr_menu_dto.ChildList.extend(curr_child_menu_info.__dict__)
+                curr_menu_dto.ChildList.extend(curr_child_menu_info)
             else:
                 self.__get_child_cote_menu_item_list(curr_menu_dto, child_menu_list, child_menu_info_list)
 
-        menu_item.ChildList.append(curr_child_menu_info.__dict__)
-        menu_item_list.append(menu_item.__dict__)
+            menu_item.ChildList.append(curr_menu_dto.__dict__)
+            menu_item_list.append(menu_item.__dict__)
 
         return menu_item_list
 
@@ -398,9 +398,9 @@ class PowerModel():
         menu_role_list = []
         rowle_power_list = RolePowerModelEx(self.db_connect_key).get_list("MenuID=%s", params=menu_id)
         if rowle_power_list:
-            role_info_list = RoleInfoModel(self.db_connect_key).get_list("RoleID IN (" + ','.join("'" + str(item.RoleID) + "'" for item in rowle_power_list) + ")")
-            role_user_list = RoleUserModel(self.db_connect_key).get_list("RoleID IN (" + ','.join("'" + str(item.RoleID) + "'" for item in rowle_power_list) + ")")
-            user_info_list = UserInfoModel(self.db_connect_key).get_list("UserID IN (" + ','.join("'" + str(item.UserID) + "'" for item in role_user_list) + ")")
+            role_info_list = RoleInfoModel(self.db_connect_key).get_list("RoleID IN ("+','.join("'"+str(item.RoleID)+"'" for item in rowle_power_list)+")")
+            role_user_list = RoleUserModel(self.db_connect_key).get_list("RoleID IN ("+','.join("'"+str(item.RoleID)+"'" for item in rowle_power_list)+")")
+            user_info_list = UserInfoModel(self.db_connect_key).get_list("UserID IN ("+','.join("'"+str(item.UserID)+"'" for item in role_user_list)+")")
             for curr_role_info in role_info_list:
                 curr_user_info_list = [i for j in [i.UserID for i in role_user_list if i.RoleID == curr_role_info.RoleID] for i in user_info_list if j in i.UserID]
                 info = {}
